contracts\_lib\_py.templates.compute\_execution\_template module
================================================================

.. automodule:: contracts_lib_py.templates.compute_execution_template
   :members:
   :undoc-members:
   :show-inheritance:
